@@ -1,8 +1,8 @@
 # -*- coding: utf-8 -*-
 
 # 设置管理域名 & 上传域名
-PUT_URL = ''
-MGR_URL = ''
+PUT_URL = 'http://'
+MGR_URL = 'http://'
 
 # 设置分片上传的块大小和片大小，单位均为字节
 _BLOCK_SIZE = 1024 * 1024 * 4
